/**
  * A PDF viewer for C Suite.
  * Copyright 2019 CuboCore Group
  *
  * This file is a part of QtPDF module from Qt-Labs (https://code.qt.io/cgit/qt-labs/qtpdf.git/).
  * Suitable modifications have been made to meet the needs of CorePDF.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, vsit http://www.gnu.org/licenses/.
  **/

#include "Navigation.hpp"
#include "Document.hpp"

#include <QPointer>

CorePDF::Navigation::Navigation(QObject *parent) : QObject(parent)
{
	impl = new NavigationImpl(this);
}


CorePDF::Navigation::~Navigation()
{
	delete impl;
}


CorePDF::Document * CorePDF::Navigation::document() const
{
	return impl->m_document;
}


void CorePDF::Navigation::setDocument(Document *document)
{
	if (impl->m_document == document)
	{
		return;
	}

	if (impl->m_document)
	{
		disconnect(impl->m_documentStatusChangedConnection);
	}

	impl->m_document = document;
	emit documentChanged(impl->m_document);

	if (impl->m_document)
	{
		impl->m_documentStatusChangedConnection = connect(impl->m_document.data(), &Document::statusChanged, this, [this](){
			impl->documentStatusChanged();
		});
	}

	impl->update();
}


int CorePDF::Navigation::currentPage() const
{
	return impl->m_currentPage;
}


void CorePDF::Navigation::setCurrentPage(int newPage)
{
	if ((newPage < 0) || (newPage >= impl->m_pageCount))
	{
		return;
	}

	if (impl->m_currentPage == newPage)
	{
		return;
	}

	impl->m_currentPage = newPage;
	emit currentPageChanged(impl->m_currentPage);

	impl->updatePrevNext();
}


int CorePDF::Navigation::pageCount() const
{
	return impl->m_pageCount;
}


bool CorePDF::Navigation::canGoToPreviousPage() const
{
	return impl->m_canGoToPreviousPage;
}


bool CorePDF::Navigation::canGoToNextPage() const
{
	return impl->m_canGoToNextPage;
}


void CorePDF::Navigation::goToPreviousPage()
{
	if (impl->m_currentPage > 0)
	{
		setCurrentPage(impl->m_currentPage - 1);
	}
}


void CorePDF::Navigation::goToNextPage()
{
	if (impl->m_currentPage < impl->m_pageCount - 1)
	{
		setCurrentPage(impl->m_currentPage + 1);
	}
}
