/**
  * A PDF viewer for C Suite.
  * Copyright 2019 CuboCore Group
  *
  * This file is a part of QtPDF module from Qt-Labs (https://code.qt.io/cgit/qt-labs/qtpdf.git/).
  * Suitable modifications have been made to meet the needs of CorePDF.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, vsit http://www.gnu.org/licenses/.
  **/

#pragma once

#include "Renderer.hpp"
#include "RenderOptions.hpp"

namespace CorePDF {
class Page;
}

class RenderTask : public QObject, public QRunnable {
	Q_OBJECT;

public:
	RenderTask(CorePDF::Page *pg, QSize imgSz, const CorePDF::RenderOptions &opts, qint64 id);

	int pageNumber();
	qint64 requestId();
	QSize imageSize();

	void invalidate();

	void run();

private:
	CorePDF::Page *mPage;
	QSize mImgSize;
	CorePDF::RenderOptions mOpts;
	qint64 mId;

Q_SIGNALS:
	void imageReady(int pageNo, QImage image, qint64 id);
};
